# Toast4Windows
Python library based on C++ to show Windows 10 based toast notification.

Usage :

from toast4windows import custom_notification

custom_notification(app_id="example app",
                     title="Toast4Windows demo",
                     msg="Hello World!")
                     
![image1](https://user-images.githubusercontent.com/16394203/127767333-c195f613-9415-4719-960e-e5a1293f6e52.PNG)

